@@ -11,6 +11,7 @@ from .base import FS
 from .compress import write_zip
 from .enums import ResourceType
 from .info import Info
+from .iotools import RawWrapper
 from .memoryfs import MemoryFS
 from .opener import open_fs
 from .path import dirname, normpath, relpath
@@ -270,12 +271,14 @@ class ReadZipFS(FS):
         if 'w' in mode or '+' in mode or 'a' in mode:
             raise errors.ResourceReadOnly(path)
 
-        if not self._directory.isfile(path):
+        if not self._directory.exists(path):
             raise errors.ResourceNotFound(path)
+        elif self._directory.isdir(path):
+            raise errors.FileExpected(path)
 
         zip_name = self._path_to_zip_name(path)
         bin_file = self._zip.open(zip_name, 'r')
-        return bin_file
+        return RawWrapper(bin_file)
 
     def remove(self, path):
         self.check()
@@ -315,4 +318,3 @@ if __name__ == "__main__":  # pragma: nocover
         zip_fs.settext('foo/bar/baz.txt', 'Hello, World')
         print(zip_fs)
         print(repr(zip_fs))
-
